@@ -99,7 +99,7 @@ const patchScriptlet = (content, arglist) => {
 };
 
 const requote = s => {
-    if ( /^(["'`]).+\1$|,/.test(s) === false ) { return s; }
+    if ( /^(["'`]).*\1$|,|^$/.test(s) === false ) { return s; }
     if ( s.includes("'") === false ) { return `'${s}'`; }
     if ( s.includes('"') === false ) { return `"${s}"`; }
     if ( s.includes('`') === false ) { return `\`${s}\``; }
