@@ -106,36 +106,6 @@ const contentScriptRegisterer = new (class {
 
 /******************************************************************************/
 
-const mainWorldInjector = (( ) => {
-    const parts = [
-        '(',
-        function(injector, details) {
-            if ( typeof self.uBO_scriptletsInjected === 'string' ) { return; }
-            const doc = document;
-            if ( doc.location === null ) { return; }
-            const hostname = doc.location.hostname;
-            if ( hostname !== '' && details.hostname !== hostname ) { return; }
-            injector(doc, details);
-            return 0;
-        }.toString(),
-        ')(',
-            vAPI.scriptletsInjector, ', ',
-            'json-slot',
-        ');',
-    ];
-    const jsonSlot = parts.indexOf('json-slot');
-    return {
-        assemble: function(hostname, details) {
-            parts[jsonSlot] = JSON.stringify({
-                hostname,
-                scriptlets: details.mainWorld,
-                filters: details.filters,
-            });
-            return parts.join('');
-        },
-    };
-})();
-
 const isolatedWorldInjector = (( ) => {
     const parts = [
         '(',
@@ -334,7 +304,7 @@ export class ScriptletFilteringEngineEx extends ScriptletFilteringEngine {
 
         const contentScript = [];
         if ( scriptletDetails.mainWorld ) {
-            contentScript.push(mainWorldInjector.assemble(hostname, scriptletDetails));
+            contentScript.push(vAPI.scriptletsInjector(hostname, scriptletDetails));
         }
         if ( scriptletDetails.isolatedWorld ) {
             contentScript.push(isolatedWorldInjector.assemble(hostname, scriptletDetails));
